==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/engines/glk/alan2/types.cpp <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#include "glk/alan2/types.h"

namespace Glk {
namespace Alan2 {

// This works around gcc errors for passing packed structure fields
static void syncVal(Common::Serializer &s, int *fld) {
	int &v = *fld;
	s.syncAsSint32LE(v);
}

void CurVars::synchronize(Common::Serializer &s) {
	syncVal(s, &vrb);
	syncVal(s, &obj);
	syncVal(s, &loc);
	syncVal(s, &act);
	syncVal(s, &tick);
	syncVal(s, &score);
	syncVal(s, &visits);
}

void EvtqElem::synchronize(Common::Serializer &s) {
	syncVal(s, &time);
	syncVal(s, &event);
	syncVal(s, &where);
}

} // End of namespace Alan2
} // End of namespace Glk

==> scummvm_2.9.1+dfsg.orig.tar.xz: scummvm-2.9.1/engines/glk/alan2/types.cpp <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "glk/alan2/types.h"

namespace Glk {
namespace Alan2 {

// This works around gcc errors for passing packed structure fields
static void syncVal(Common::Serializer &s, void *fld) {
	uint32 v = READ_UINT32(fld);
	s.syncAsSint32LE(v);
	if (s.isLoading())
		WRITE_UINT32(fld, v);
}

void CurVars::synchronize(Common::Serializer &s) {
	syncVal(s, &vrb);
	syncVal(s, &obj);
	syncVal(s, &loc);
	syncVal(s, &act);
	syncVal(s, &tick);
	syncVal(s, &score);
	syncVal(s, &visits);
}

void EvtqElem::synchronize(Common::Serializer &s) {
	syncVal(s, &time);
	syncVal(s, &event);
	syncVal(s, &where);
}

} // End of namespace Alan2
} // End of namespace Glk
